#include "p18f14k22.h"

#include "DOGM162.h"

#include "DOGM162_Driver.h"

#include "Interrupts.h"

#pragma config FOSC = IRC, FCMEN = OFF, IESO = OFF                          // CONFIG1H
#pragma config PWRTEN = OFF, BOREN = OFF, BORV = 30                         // CONFIG2L
#pragma config WDTEN = OFF, WDTPS = 128                                     // CONFIG2H
#pragma config MCLRE = ON                                                   // CONFIG3H
#pragma config STVREN = ON, LVP = OFF, XINST = OFF                          // CONFIG4L
#pragma config CP0 = OFF, CP1 = OFF                                         // CONFIG5L
#pragma config CPB = OFF, CPD = OFF                                         // CONFIG5H
#pragma config WRT0 = OFF, WRT1 = OFF                                       // CONFIG6L
#pragma config WRTB = OFF, WRTC = OFF, WRTD = OFF                           // CONFIG6H

void PIC_Init(void)
{
    //Freq 64Mhz
    OSCCON = 0x70;
    OSCTUNEbits.PLLEN = 1;

    TRISA = 0x00;
    TRISB = 0x00;
    TRISC = 0xF0;

    LATA = 0x00;
    LATB = 0x00;
    LATC = 0x00;

    ADCON1 = 0x0F; //Dsactiver le convertisseur analogique numerique

    CCP1CON = 0x00; //Dsactiver le module CCP

    ANSELH = 0x00; //Entres digitales

    //Initialisation interruptions
    RCONbits.IPEN = 1; //Activation des priorites des interruptions
    INTCONbits.GIEL = 1; //Activation des interruptions  basse priorite
    INTCONbits.GIEH = 1; //Activation des interruptions  haute priorite

    //Initialisation mode capture
    CCP1CON = 0b00000101; //Mode capture front montant
    PIE1bits.CCP1IE = 0; //Activation interruption
    PIR1bits.CCP1IF = 0; //Drapeau interruption  0
    IPR1bits.CCP1IP = 0; //Priorit interruption basse

    //Initialisation Timer0
    INTCONbits.TMR0IF = 0; //Drapeau interruption  0
    INTCON2bits.TMR0IP = 0; //Priorit interruption basse
    INTCONbits.TMR0IE = 1; //Activation interruption
    T0CON = 0b0000111; //Prescale
    TMR0H = 0x00;
    TMR0L = 0x00;
}

void main(void)
{
    PIC_Init();
    DOGM_Init();

    DOGM_Display(0x44); //D
    DOGM_Display(0x41); //A
    DOGM_Display(0x54); //T
    DOGM_Display(0x41); //A
    DOGM_Display(0x20); //
    DOGM_Display(0x44); //D
    DOGM_Display(0x49); //I
    DOGM_Display(0x53); //S
    DOGM_Display(0x50); //P
    DOGM_Display(0x4C); //L
    DOGM_Display(0x41); //A
    DOGM_Display(0x59); //Y
    DOGM_Display(0x20); //
    DOGM_Display(0x56); //V
    DOGM_Display(0x31); //1
    DOGM_Display(0x02); //Retour
    DOGM_Display(0x54); //T
    DOGM_Display(0x48); //H
    DOGM_Display(0x49); //I
    DOGM_Display(0x45); //E
    DOGM_Display(0x4E); //N
    DOGM_Display(0x4F); //O
    DOGM_Display(0x55); //U

    T0CONbits.TMR0ON = 1; //Timer0 ON

    while(1)
    {
        //Chip Enable
        if(DATA_CE == 0)
        {
            PIE1bits.CCP1IE = 1;
        }
        else
        {
            if(T0CONbits.TMR0ON == 0)
            {
                PIE1bits.CCP1IE = 0;
                DOGM_Clear();
                DelayMS(1000);
            }
        }
    }
}