#include "p18f14k22.h"

#include "DOGM162_Driver.h"

#include "delays.h"

char cursor_pos = 1;
char cursor_line = 1;

void DOGM_Init(void)
{
    AFF_DATA = 0x00;

    AFF_RW  = 0;
    AFF_RS  = 0;
    AFF_E   = 0;

    DelayMS(45);

    DOGM_command_once(0x30); //Function Set
    DelayMS(2);

    DOGM_command_once(0x30); //Function Set
    Delay10US(3);

    DOGM_command_once(0x30); //Function Set
    Delay10US(3);

    DOGM_command_once(0x20); //Function Set
    Delay10US(3);

    DOGM_command(0x29); //Function Set
    Delay10US(3);

    DOGM_command(0x1C); //Internal OSC frequency - Bias Set
    Delay10US(3);

    DOGM_command(0x52); //Power Control
    Delay10US(3);

    DOGM_command(0x69); //Follower Control
    Delay10US(3);

    DOGM_command(0x74); //Constrast Set
    Delay10US(3);

    DOGM_command(0x28); //Function Set
    Delay10US(3);

    DOGM_command(0x0C); //Display ON/OFF 0x0C
    Delay10US(3);

    DOGM_command(0x01); //Clear Display
    DelayMS(3);

    DOGM_command(0x06); //Entry Mode Set
    Delay10US(3);
}

void DOGM_Clear(void)
{
    DOGM_command(0x01); //Clear Display
    DelayMS(3);
    cursor_pos = 1;
    cursor_line = 1;
}

void DelayMS(int tmp)
{
    int i = 0;
    for(i=0; i<tmp; i++)
    {
        Delay1KTCYx(16);
    }
}

void Delay10US(int tmp)
{
    int i = 0;
    for(i=0; i<tmp; i++)
    {
        Delay10TCYx(16);
    }
}

void DOGM_data(unsigned char data)
{
    AFF_DATA = data;
    AFF_E = 1;
    Delay10US(1);
    AFF_E = 0;
    Delay10US(1);
}

void DOGM_command(unsigned char cmd)
{
    DelayMS(1);
    AFF_RW = 0;
    AFF_RS = 0;
    DOGM_data(cmd & 0xF0);
    DOGM_data((cmd & 0x0F) << 4);
}

void DOGM_command_once(unsigned char cmd)
{
   AFF_RW = 0;
   AFF_RS = 0;
   DOGM_data(cmd & 0xF0);
}

void DOGM_writechar(char data)
{
   AFF_RW = 0;
   AFF_RS = 1;
   DOGM_data(data & 0xF0);
   DOGM_data((data & 0x0F) << 4);
}

void DOGM_position(unsigned char line, unsigned char position)
{
   unsigned char address;
   address = position - 1;
   if(line == 2)address += 0x40;
   address += 0b10000000;
   DelayMS(1);
   DOGM_command(address);
}

void DOGM_Display(unsigned int character)
{
    unsigned char address;

    if(character == 0x01)
    {
        DOGM_Clear();
    }
    else if(character == 0x02)
    {
        if(cursor_line == 1)cursor_line = 2;
        else cursor_line = 1;
        cursor_pos = 1;
    }
    else
    {
        address = cursor_pos - 1;
        if(cursor_line == 2)address += 0x40;
        address += 0b10000000;
        DelayMS(1);
        DOGM_command(address);

        DOGM_writechar(character);

        if(cursor_pos < 16)cursor_pos++;
        else cursor_pos = 1;
    }
}